==> qtjambi-help-5.15-sources.jar: io/qt/help/QHelpContentModel.java <==
package io.qt.help;


/**
 * <p>Model that supplies content to views</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qhelpcontentmodel.html">QHelpContentModel</a></p>
 */
public final class QHelpContentModel extends io.qt.core.QAbstractItemModel
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpContentModel.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpcontentmodel.html#contentsCreated">QHelpContentModel::contentsCreated()</a></p>
     */
    public final Signal0 contentsCreated = new Signal0();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpcontentmodel.html#contentsCreationStarted">QHelpContentModel::contentsCreationStarted()</a></p>
     */
    public final Signal0 contentsCreationStarted = new Signal0();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpcontentmodel.html#contentItemAt">QHelpContentModel::contentItemAt(QModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpContentItem contentItemAt(io.qt.core.QModelIndex index){
        return contentItemAt_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpContentItem contentItemAt_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpcontentmodel.html#createContents">QHelpContentModel::createContents(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void createContents(java.lang.String customFilterName){
        createContents_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), customFilterName);
    }
    
    @io.qt.QtUninvokable
    private native void createContents_native_cref_QString(long __this__nativeId, java.lang.String customFilterName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpcontentmodel.html#isCreatingContents">QHelpContentModel::isCreatingContents()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isCreatingContents(){
        return isCreatingContents_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isCreatingContents_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractitemmodel.html#columnCount">QAbstractItemModel::columnCount(QModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public int columnCount(io.qt.core.QModelIndex parent){
        return columnCount_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), parent);
    }
    
    @io.qt.QtUninvokable
    private native int columnCount_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractitemmodel.html#data">QAbstractItemModel::data(QModelIndex,int)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.Object data(io.qt.core.QModelIndex index, int role){
        return data_native_cref_QModelIndex_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index, role);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object data_native_cref_QModelIndex_int_constfct(long __this__nativeId, io.qt.core.QModelIndex index, int role);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractitemmodel.html#index">QAbstractItemModel::index(int,int,QModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.core.QModelIndex index(int row, int column, io.qt.core.QModelIndex parent){
        return index_native_int_int_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), row, column, parent);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QModelIndex index_native_int_int_cref_QModelIndex_constfct(long __this__nativeId, int row, int column, io.qt.core.QModelIndex parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractitemmodel.html#parent">QAbstractItemModel::parent(QModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.core.QModelIndex parent(io.qt.core.QModelIndex index){
        return parent_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QModelIndex parent_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractitemmodel.html#rowCount">QAbstractItemModel::rowCount(QModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public int rowCount(io.qt.core.QModelIndex parent){
        return rowCount_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), parent);
    }
    
    @io.qt.QtUninvokable
    private native int rowCount_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpContentModel(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-help-6.2.1-sources.jar: io/qt/help/QHelpContentModel.java <==
package io.qt.help;


/**
 * <p>Model that supplies content to views</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qhelpcontentmodel.html">QHelpContentModel</a></p>
 */
public final class QHelpContentModel extends io.qt.core.QAbstractItemModel
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpContentModel.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpcontentmodel.html#contentsCreated">QHelpContentModel::contentsCreated()</a></p>
     */
    public final Signal0 contentsCreated = new Signal0();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpcontentmodel.html#contentsCreationStarted">QHelpContentModel::contentsCreationStarted()</a></p>
     */
    public final Signal0 contentsCreationStarted = new Signal0();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpcontentmodel.html#contentItemAt">QHelpContentModel::contentItemAt(QModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpContentItem contentItemAt(io.qt.core.QModelIndex index){
        return contentItemAt_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpContentItem contentItemAt_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex index);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpcontentmodel.html#createContents">QHelpContentModel::createContents(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void createContents(java.lang.String customFilterName){
        createContents_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), customFilterName);
    }
    
    @io.qt.QtUninvokable
    private native void createContents_native_cref_QString(long __this__nativeId, java.lang.String customFilterName);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpcontentmodel.html#isCreatingContents">QHelpContentModel::isCreatingContents()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isCreatingContents(){
        return isCreatingContents_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isCreatingContents_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodel.html#columnCount">QAbstractItemModel::columnCount(QModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public int columnCount(io.qt.core.QModelIndex parent){
        return columnCount_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), parent);
    }
    
    @io.qt.QtUninvokable
    private native int columnCount_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodel.html#data">QAbstractItemModel::data(QModelIndex,int)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.Object data(io.qt.core.QModelIndex index, int role){
        return data_native_cref_QModelIndex_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index, role);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object data_native_cref_QModelIndex_int_constfct(long __this__nativeId, io.qt.core.QModelIndex index, int role);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodel.html#index">QAbstractItemModel::index(int,int,QModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.core.QModelIndex index(int row, int column, io.qt.core.QModelIndex parent){
        return index_native_int_int_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), row, column, parent);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QModelIndex index_native_int_int_cref_QModelIndex_constfct(long __this__nativeId, int row, int column, io.qt.core.QModelIndex parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodel.html#parent">QAbstractItemModel::parent(QModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.core.QModelIndex parent(io.qt.core.QModelIndex index){
        return parent_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QModelIndex parent_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex index);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodel.html#rowCount">QAbstractItemModel::rowCount(QModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public int rowCount(io.qt.core.QModelIndex parent){
        return rowCount_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), parent);
    }
    
    @io.qt.QtUninvokable
    private native int rowCount_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpContentModel(QPrivateConstructor p) { super(p); } 
    
}
